@@ -22,7 +22,7 @@ class DataAccess:
     #           spark_context-> spark的上下文
     # return： 以spark dataFrame的数据结构返回
     @staticmethod
-    def query_pg(sql):
+    def query_pg_inner(sql):
         try:
             conn = psycopg2.connect(
                 database=config.get("pg", "database"), user=config.get("pg", "user"),
@@ -30,11 +30,17 @@ class DataAccess:
                 port=config.get("pg", "port"))
             cursor = conn.cursor()
             cursor.execute(sql)
-            pdf = pd.DataFrame(cursor.fetchall())
-            sdf = cf.build_sql_context().createDataFrame(pdf)
+            pgdata = cursor.fetchall()
         except psycopg2.DatabaseError, exception:
             print (exception)
             sys.exit(1)
+        return pgdata
+
+    @staticmethod
+    def query_pg(sql):
+        pgdata = DataAccess.query_pg_inner(sql)
+        pdf = pd.DataFrame(pgdata)
+        sdf = cf.build_sql_context().createDataFrame(pdf)
         return sdf
 
     # function: query_hive 查询hive数据库的接口
