@@ -6,7 +6,7 @@ import ConfigParser
 from pyspark import SparkConf
 
 curr_dir = os.path.dirname(os.path.realpath(__file__))
-relative_path = "\\..\\..\\..\\resources"
+relative_path = os.sep + ".." + os.sep + ".." + os.sep + ".." + os.sep + "resources"
 
 
 def load(filename):
